
[![](https://codecov.io/gh/nickderobertis/pl-uf-thesis/branch/master/graph/badge.svg)](https://codecov.io/gh/nickderobertis/pl-uf-thesis)

#  pl-uf-thesis

## Overview

University of Florida Thesis/Dissertation Template for Pyexlatex

## Getting Started

Install `pl-uf-thesis`:

```
pip install pl-uf-thesis
```

A simple example:

```python
import plufthesis

# Do something with plufthesis
```

## Links

See the
[documentation here.](
https://nickderobertis.github.io/pl-uf-thesis/
)

## Author

Created by Nick DeRobertis. MIT License.